1
2
3
4
5
6
7
8
9
10
11
12
13
14
15
16
17
18
19
20
21
22
23
24
25
26
27
28
29
30
31
32
33
34
35
36
37
38
39
40
41
42
43
44
45
46
47
48
49
50
51
52
53
54
55
56
57
58
59
60
61
62
63
64
65
66
67
68
69
70
71
72
73
74
75
76
77
78
79
80
81
82
83
84
85
86
87
88
89
90
91
92
93
94
95
96
97
98
99
100
101
102
103
104
105
106
107
108
109
110
111
112
113
114
115
116
117
118
119
120
121
122
123
124
125
126
127
128
129
130
131
132
133
134
135
136
137
138
139
140
141
142
143
144
145
146
147
148
149
150
151
152
153
154
155
156
157
158
159
160
161
162
163
164
165
166
167
168
169
170
171
172
173
174
175
176
177
178
179
180
181
182
183
184
185
186
187
188
189
190
191
192
193
194
195
196
197
198
199
200
201
202
203
204
205
206
207
208
209
210
211
212
213
214
215
216
217
218
219
220
221
222
223
224
225
226
227
228
229
230
231
232
233
234
235
236
237
238
239
240
241
242
243
244
245
246
247
248
249
250
251
252
253
254
255
256
257
258
259
260
261
262
263
264
265
266
267
268
269
270
271
272
273
274
275
276
277
278
279
280
281
282
283
284
285
286
287
288
289
290
291
292
293
294
295
296
297
298
299
300
301
302
303
304
305
306
307
308
309
310
311
312
313
314
315
316
317
318
319
320
321
322
323
324
325
326
327
328
329
330
331
332
333
334
335
336
337
338
339
340
341
342
343
344
345
346
347
348
349
350
351
352
353
354
355
356
357
358
359
360
361
362
363
364
365
366
367
368
369
370
371
372
373
374
375
376
377
378
379
380
381
382
383
384
385
386
387
388
389
390
391
392
393
394
395
396
397
398
399
400
401
402
403
404
405
406
407
408
409
410
411
412
413
414
415
416
417
418
419
420
421
422
423
424
425
426
427
428
429
430
431
432
433
434
435
436
437
438
439
440
441
442
443
444
445
446
447
448
449
450
451
452
453
454
455
456
457
458
459
460
461
462
463
464
465
466
467
468
469
470
471
472
473
474
475
476
477
478
479
480
481
482
483
484
485
486
487
488
489
490
491
492
493
494
495
496
497
498
499
500
501
502
503
504
505
506
507
508
509
510
511
512
513
514
515
516
517
518
519
520
521
522
523
524
525
526
527
528
529
530
531
532
533
534
535
536
537
|
From 7c321c4d75c7c80d899db962804d288ed7db162e Mon Sep 17 00:00:00 2001
From: Mike Perry <mikeperry-git@torproject.org>
Date: Thu, 7 Jun 2012 15:26:13 -0700
Subject: [PATCH 18/20] Adapt Steven Michaud's Mac crashfix patch
Source is: https://bugzilla.mozilla.org/show_bug.cgi?id=715885#c35
Some minor tweaks were needed to get it to apply and to compile on
MacOS.
---
widget/Makefile.in | 1 +
widget/cocoa/nsChildView.mm | 28 +++++++++++------
widget/gtk2/nsDragService.cpp | 2 +-
widget/gtk2/nsWindow.cpp | 2 +-
widget/nsIDragService.idl | 4 +--
widget/nsPIDragService.idl | 48 +++++++++++++++++++++++++++++
widget/qt/nsDragService.h | 2 +
widget/windows/Makefile.in | 4 ++
widget/windows/nsDragService.cpp | 13 +++++---
widget/windows/nsDragService.h | 12 +++---
widget/windows/nsNativeDragSource.cpp | 7 ++--
widget/windows/nsNativeDragTarget.cpp | 28 ++++++++++------
widget/windows/nsPIDragServiceWindows.idl | 46 +++++++++++++++++++++++++++
widget/xpwidgets/nsBaseDragService.cpp | 16 +++++++++-
widget/xpwidgets/nsBaseDragService.h | 9 ++---
15 files changed, 176 insertions(+), 46 deletions(-)
create mode 100644 widget/nsPIDragService.idl
create mode 100644 widget/windows/nsPIDragServiceWindows.idl
diff --git a/widget/Makefile.in b/widget/Makefile.in
index 4a3405b..4c105a4 100644
--- a/widget/Makefile.in
+++ b/widget/Makefile.in
@@ -138,6 +138,7 @@ XPIDLSRCS = \
nsIClipboardDragDropHooks.idl \
nsIClipboardDragDropHookList.idl \
nsIDragSession.idl \
+ nsPIDragService.idl \
nsIDragService.idl \
nsIFormatConverter.idl \
nsIClipboard.idl \
diff --git a/widget/cocoa/nsChildView.mm b/widget/cocoa/nsChildView.mm
index 0db6b1c..8d59716 100644
--- a/widget/cocoa/nsChildView.mm
+++ b/widget/cocoa/nsChildView.mm
@@ -4555,11 +4555,12 @@ NSEvent* gLastDragMouseDownEvent = nil;
if (!dragService) {
dragService = do_GetService(kDragServiceContractID);
}
+ nsCOMPtr<nsPIDragService> dragServicePriv = do_QueryInterface(dragService);
if (dragService) {
NSPoint pnt = [NSEvent mouseLocation];
FlipCocoaScreenCoordinate(pnt);
- dragService->DragMoved(NSToIntRound(pnt.x), NSToIntRound(pnt.y));
+ dragServicePriv->DragMoved(NSToIntRound(pnt.x), NSToIntRound(pnt.y));
}
}
@@ -4580,11 +4581,13 @@ NSEvent* gLastDragMouseDownEvent = nil;
}
if (mDragService) {
- // set the dragend point from the current mouse location
- nsDragService* dragService = static_cast<nsDragService *>(mDragService);
- NSPoint pnt = [NSEvent mouseLocation];
- FlipCocoaScreenCoordinate(pnt);
- dragService->SetDragEndPoint(nsIntPoint(NSToIntRound(pnt.x), NSToIntRound(pnt.y)));
+ nsCOMPtr<nsPIDragService> dragServicePriv = do_QueryInterface(mDragService);
+ if (dragServicePriv) {
+ // set the dragend point from the current mouse location
+ NSPoint pnt = [NSEvent mouseLocation];
+ FlipCocoaScreenCoordinate(pnt);
+ dragServicePriv->SetDragEndPoint(NSToIntRound(pnt.x), NSToIntRound(pnt.y));
+ }
// XXX: dropEffect should be updated per |operation|.
// As things stand though, |operation| isn't well handled within "our"
@@ -4595,10 +4598,15 @@ NSEvent* gLastDragMouseDownEvent = nil;
// value for NSDragOperationGeneric that is passed by other applications.
// All that said, NSDragOperationNone is still reliable.
if (operation == NSDragOperationNone) {
- nsCOMPtr<nsIDOMDataTransfer> dataTransfer;
- dragService->GetDataTransfer(getter_AddRefs(dataTransfer));
- if (dataTransfer)
- dataTransfer->SetDropEffectInt(nsIDragService::DRAGDROP_ACTION_NONE);
+ nsCOMPtr<nsIDragSession> dragSession;
+ mDragService->GetCurrentSession(getter_AddRefs(dragSession));
+ if (dragSession) {
+ nsCOMPtr<nsIDOMDataTransfer> dataTransfer;
+ dragSession->GetDataTransfer(getter_AddRefs(dataTransfer));
+ if (dataTransfer) {
+ dataTransfer->SetDropEffectInt(nsIDragService::DRAGDROP_ACTION_NONE);
+ }
+ }
}
mDragService->EndDragSession(true);
diff --git a/widget/gtk2/nsDragService.cpp b/widget/gtk2/nsDragService.cpp
index be8f388..99d3878 100644
--- a/widget/gtk2/nsDragService.cpp
+++ b/widget/gtk2/nsDragService.cpp
@@ -1332,7 +1332,7 @@ nsDragService::SourceEndDragSession(GdkDragContext *aContext,
GdkDisplay* display = gdk_display_get_default();
if (display) {
gdk_display_get_pointer(display, NULL, &x, &y, NULL);
- SetDragEndPoint(nsIntPoint(x, y));
+ SetDragEndPoint(x, y);
}
// Either the drag was aborted or the drop occurred outside the app.
diff --git a/widget/gtk2/nsWindow.cpp b/widget/gtk2/nsWindow.cpp
index 9de734e..81fe553 100644
--- a/widget/gtk2/nsWindow.cpp
+++ b/widget/gtk2/nsWindow.cpp
@@ -3517,7 +3517,7 @@ nsWindow::OnDragDropEvent(GtkWidget *aWidget,
if (display) {
// get the current cursor position
gdk_display_get_pointer(display, NULL, &x, &y, NULL);
- ((nsDragService *)dragService.get())->SetDragEndPoint(nsIntPoint(x, y));
+ ((nsDragService *)dragService.get())->SetDragEndPoint(x, y);
}
dragService->EndDragSession(true);
diff --git a/widget/nsIDragService.idl b/widget/nsIDragService.idl
index e42c578..ef8c46f 100644
--- a/widget/nsIDragService.idl
+++ b/widget/nsIDragService.idl
@@ -48,7 +48,7 @@ interface nsIDOMDragEvent;
interface nsIDOMDataTransfer;
interface nsISelection;
-[scriptable, uuid(82B58ADA-F490-4C3D-B737-1057C4F1D052), builtinclass]
+[scriptable, uuid(82B58ADA-F490-4C3D-B737-1057C4F1D052)]
interface nsIDragService : nsISupports
{
const long DRAGDROP_ACTION_NONE = 0;
@@ -145,8 +145,6 @@ interface nsIDragService : nsISupports
*/
void suppress();
void unsuppress();
-
- [noscript] void dragMoved(in long aX, in long aY);
};
diff --git a/widget/nsPIDragService.idl b/widget/nsPIDragService.idl
new file mode 100644
index 0000000..93a144d
--- /dev/null
+++ b/widget/nsPIDragService.idl
@@ -0,0 +1,48 @@
+/* ***** BEGIN LICENSE BLOCK *****
+ * Version: MPL 1.1/GPL 2.0/LGPL 2.1
+ *
+ * The contents of this file are subject to the Mozilla Public License Version
+ * 1.1 (the "License"); you may not use this file except in compliance with
+ * the License. You may obtain a copy of the License at
+ * http://www.mozilla.org/MPL/
+ *
+ * Software distributed under the License is distributed on an "AS IS" basis,
+ * WITHOUT WARRANTY OF ANY KIND, either express or implied. See the License
+ * for the specific language governing rights and limitations under the
+ * License.
+ *
+ * The Original Code is mozilla.org code.
+ *
+ * The Initial Developer of the Original Code is
+ * The Mozilla Foundation.
+ * Portions created by the Initial Developer are Copyright (C) 2012
+ * the Initial Developer. All Rights Reserved.
+ *
+ * Contributor(s):
+ * Steven Michaud <smichaud@pobox.com>
+ *
+ * Alternatively, the contents of this file may be used under the terms of
+ * either the GNU General Public License Version 2 or later (the "GPL"), or
+ * the GNU Lesser General Public License Version 2.1 or later (the "LGPL"),
+ * in which case the provisions of the GPL or the LGPL are applicable instead
+ * of those above. If you wish to allow use of your version of this file only
+ * under the terms of either the GPL or the LGPL, and not to allow others to
+ * use your version of this file under the terms of the MPL, indicate your
+ * decision by deleting the provisions above and replace them with the notice
+ * and other provisions required by the GPL or the LGPL. If you do not delete
+ * the provisions above, a recipient may use your version of this file under
+ * the terms of any one of the MPL, the GPL or the LGPL.
+ *
+ * ***** END LICENSE BLOCK ***** */
+
+#include "nsISupports.idl"
+
+[scriptable, uuid(FAD8C90B-8E1D-446A-9B6C-241486A85CBD)]
+interface nsPIDragService : nsISupports
+{
+ void dragMoved(in long aX, in long aY);
+
+ PRUint16 getInputSource();
+
+ void setDragEndPoint(in long aX, in long aY);
+};
diff --git a/widget/qt/nsDragService.h b/widget/qt/nsDragService.h
index 5a3e5bb..50dcfac 100644
--- a/widget/qt/nsDragService.h
+++ b/widget/qt/nsDragService.h
@@ -50,6 +50,8 @@ public:
NS_DECL_ISUPPORTS
NS_DECL_NSIDRAGSERVICE
+ NS_IMETHOD DragMoved(PRInt32 aX, PRInt32 aY);
+
nsDragService();
private:
diff --git a/widget/windows/Makefile.in b/widget/windows/Makefile.in
index df811ac..8d5ea4b 100644
--- a/widget/windows/Makefile.in
+++ b/widget/windows/Makefile.in
@@ -120,6 +120,10 @@ ifdef MOZ_ENABLE_D3D10_LAYER
DEFINES += -DMOZ_ENABLE_D3D10_LAYER
endif
+XPIDLSRCS += \
+ nsPIDragServiceWindows.idl \
+ $(NULL)
+
SHARED_LIBRARY_LIBS = \
../xpwidgets/$(LIB_PREFIX)xpwidgets_s.$(LIB_SUFFIX) \
$(NULL)
diff --git a/widget/windows/nsDragService.cpp b/widget/windows/nsDragService.cpp
index b6b5b62..9657263 100644
--- a/widget/windows/nsDragService.cpp
+++ b/widget/windows/nsDragService.cpp
@@ -97,6 +97,8 @@ nsDragService::~nsDragService()
NS_IF_RELEASE(mDataObject);
}
+NS_IMPL_ISUPPORTS_INHERITED1(nsDragService, nsBaseDragService, nsPIDragServiceWindows)
+
bool
nsDragService::CreateDragImage(nsIDOMNode *aDOMNode,
nsIScriptableRegion *aRegion,
@@ -347,7 +349,7 @@ nsDragService::StartInvokingDragSession(IDataObject * aDataObj,
POINT cpos;
cpos.x = GET_X_LPARAM(pos);
cpos.y = GET_Y_LPARAM(pos);
- SetDragEndPoint(nsIntPoint(cpos.x, cpos.y));
+ SetDragEndPoint(cpos.x, cpos.y);
EndDragSession(true);
mDoingDrag = false;
@@ -465,25 +467,26 @@ nsDragService::GetData(nsITransferable * aTransferable, PRUint32 anItem)
//---------------------------------------------------------
NS_IMETHODIMP
-nsDragService::SetIDataObject(IDataObject * aDataObj)
+nsDragService::SetIDataObject(nsISupports * aDataObj)
{
+ IDataObject *dataObj = (IDataObject*) aDataObj;
// When the native drag starts the DragService gets
// the IDataObject that is being dragged
NS_IF_RELEASE(mDataObject);
- mDataObject = aDataObj;
+ mDataObject = dataObj;
NS_IF_ADDREF(mDataObject);
return NS_OK;
}
//---------------------------------------------------------
-void
+NS_IMETHODIMP
nsDragService::SetDroppedLocal()
{
// Sent from the native drag handler, letting us know
// a drop occurred within the application vs. outside of it.
mSentLocalDropEvent = true;
- return;
+ return NS_OK;
}
//-------------------------------------------------------------------------
diff --git a/widget/windows/nsDragService.h b/widget/windows/nsDragService.h
index 87d6cc9..04c8746 100644
--- a/widget/windows/nsDragService.h
+++ b/widget/windows/nsDragService.h
@@ -39,6 +39,7 @@
#define nsDragService_h__
#include "nsBaseDragService.h"
+#include "nsPIDragServiceWindows.h"
#include <windows.h>
#include <shlobj.h>
@@ -52,12 +53,15 @@ class nsString;
* Native Win32 DragService wrapper
*/
-class nsDragService : public nsBaseDragService
+class nsDragService : public nsBaseDragService, public nsPIDragServiceWindows
{
public:
nsDragService();
virtual ~nsDragService();
-
+
+ NS_DECL_ISUPPORTS_INHERITED
+ NS_DECL_NSPIDRAGSERVICEWINDOWS
+
// nsIDragService
NS_IMETHOD InvokeDragSession(nsIDOMNode *aDOMNode,
nsISupportsArray *anArrayTransferables,
@@ -71,13 +75,9 @@ public:
NS_IMETHOD EndDragSession(bool aDoneDrag);
// native impl.
- NS_IMETHOD SetIDataObject(IDataObject * aDataObj);
NS_IMETHOD StartInvokingDragSession(IDataObject * aDataObj,
PRUint32 aActionType);
- // A drop occurred within the application vs. outside of it.
- void SetDroppedLocal();
-
protected:
nsDataObjCollection* GetDataObjCollection(IDataObject * aDataObj);
diff --git a/widget/windows/nsNativeDragSource.cpp b/widget/windows/nsNativeDragSource.cpp
index e51101e..0fe6ffe 100644
--- a/widget/windows/nsNativeDragSource.cpp
+++ b/widget/windows/nsNativeDragSource.cpp
@@ -42,7 +42,7 @@
#include "nsIServiceManager.h"
#include "nsToolkit.h"
#include "nsWidgetsCID.h"
-#include "nsIDragService.h"
+#include "nsDragService.h"
static NS_DEFINE_IID(kCDragServiceCID, NS_DRAGSERVICE_CID);
@@ -101,9 +101,10 @@ STDMETHODIMP
nsNativeDragSource::QueryContinueDrag(BOOL fEsc, DWORD grfKeyState)
{
nsCOMPtr<nsIDragService> dragService = do_GetService(kCDragServiceCID);
- if (dragService) {
+ nsCOMPtr<nsPIDragService> dragServicePriv = do_QueryInterface(dragService);
+ if (dragServicePriv) {
DWORD pos = ::GetMessagePos();
- dragService->DragMoved(GET_X_LPARAM(pos), GET_Y_LPARAM(pos));
+ dragServicePriv->DragMoved(GET_X_LPARAM(pos), GET_Y_LPARAM(pos));
}
if (fEsc) {
diff --git a/widget/windows/nsNativeDragTarget.cpp b/widget/windows/nsNativeDragTarget.cpp
index 3362ca6..a69817c 100644
--- a/widget/windows/nsNativeDragTarget.cpp
+++ b/widget/windows/nsNativeDragTarget.cpp
@@ -205,7 +205,11 @@ nsNativeDragTarget::DispatchDragDropEvent(PRUint32 aEventType, POINTL aPT)
event.isControl = IsKeyDown(NS_VK_CONTROL);
event.isMeta = false;
event.isAlt = IsKeyDown(NS_VK_ALT);
- event.inputSource = static_cast<nsBaseDragService*>(mDragService)->GetInputSource();
+ event.inputSource = 0;
+ nsCOMPtr<nsPIDragService> dragServicePriv = do_QueryInterface(mDragService);
+ if (dragServicePriv) {
+ dragServicePriv->GetInputSource(&event.inputSource);
+ }
mWindow->DispatchEvent(&event, status);
}
@@ -292,9 +296,8 @@ nsNativeDragTarget::DragEnter(LPDATAOBJECT pIDataSource,
// This cast is ok because in the constructor we created a
// the actual implementation we wanted, so we know this is
// a nsDragService. It should be a private interface, though.
- nsDragService * winDragService =
- static_cast<nsDragService *>(mDragService);
- winDragService->SetIDataObject(pIDataSource);
+ nsCOMPtr<nsPIDragServiceWindows> winDragService = do_QueryInterface(mDragService);
+ winDragService->SetIDataObject((nsISupports*)pIDataSource);
// Now process the native drag state and then dispatch the event
ProcessDrag(NS_DRAGDROP_ENTER, grfKeyState, ptl, pdwEffect);
@@ -432,8 +435,8 @@ nsNativeDragTarget::Drop(LPDATAOBJECT pData,
// This cast is ok because in the constructor we created a
// the actual implementation we wanted, so we know this is
// a nsDragService (but it should still be a private interface)
- nsDragService* winDragService = static_cast<nsDragService*>(mDragService);
- winDragService->SetIDataObject(pData);
+ nsCOMPtr<nsPIDragServiceWindows> winDragService = do_QueryInterface(mDragService);
+ winDragService->SetIDataObject((nsISupports*)pData);
// NOTE: ProcessDrag spins the event loop which may destroy arbitrary objects.
// We use strong refs to prevent it from destroying these:
@@ -457,11 +460,14 @@ nsNativeDragTarget::Drop(LPDATAOBJECT pData,
// tell the drag service we're done with the session
// Use GetMessagePos to get the position of the mouse at the last message
// seen by the event loop. (Bug 489729)
- DWORD pos = ::GetMessagePos();
- POINT cpos;
- cpos.x = GET_X_LPARAM(pos);
- cpos.y = GET_Y_LPARAM(pos);
- winDragService->SetDragEndPoint(nsIntPoint(cpos.x, cpos.y));
+ nsCOMPtr<nsPIDragService> dragServicePriv = do_QueryInterface(mDragService);
+ if (dragServicePriv) {
+ DWORD pos = ::GetMessagePos();
+ POINT cpos;
+ cpos.x = GET_X_LPARAM(pos);
+ cpos.y = GET_Y_LPARAM(pos);
+ dragServicePriv->SetDragEndPoint(cpos.x, cpos.y);
+ }
serv->EndDragSession(true);
// release the ref that was taken in DragEnter
diff --git a/widget/windows/nsPIDragServiceWindows.idl b/widget/windows/nsPIDragServiceWindows.idl
new file mode 100644
index 0000000..c8a46dd
--- /dev/null
+++ b/widget/windows/nsPIDragServiceWindows.idl
@@ -0,0 +1,46 @@
+/* ***** BEGIN LICENSE BLOCK *****
+ * Version: MPL 1.1/GPL 2.0/LGPL 2.1
+ *
+ * The contents of this file are subject to the Mozilla Public License Version
+ * 1.1 (the "License"); you may not use this file except in compliance with
+ * the License. You may obtain a copy of the License at
+ * http://www.mozilla.org/MPL/
+ *
+ * Software distributed under the License is distributed on an "AS IS" basis,
+ * WITHOUT WARRANTY OF ANY KIND, either express or implied. See the License
+ * for the specific language governing rights and limitations under the
+ * License.
+ *
+ * The Original Code is mozilla.org code.
+ *
+ * The Initial Developer of the Original Code is
+ * The Mozilla Foundation.
+ * Portions created by the Initial Developer are Copyright (C) 2012
+ * the Initial Developer. All Rights Reserved.
+ *
+ * Contributor(s):
+ * Steven Michaud <smichaud@pobox.com>
+ *
+ * Alternatively, the contents of this file may be used under the terms of
+ * either the GNU General Public License Version 2 or later (the "GPL"), or
+ * the GNU Lesser General Public License Version 2.1 or later (the "LGPL"),
+ * in which case the provisions of the GPL or the LGPL are applicable instead
+ * of those above. If you wish to allow use of your version of this file only
+ * under the terms of either the GPL or the LGPL, and not to allow others to
+ * use your version of this file under the terms of the MPL, indicate your
+ * decision by deleting the provisions above and replace them with the notice
+ * and other provisions required by the GPL or the LGPL. If you do not delete
+ * the provisions above, a recipient may use your version of this file under
+ * the terms of any one of the MPL, the GPL or the LGPL.
+ *
+ * ***** END LICENSE BLOCK ***** */
+
+#include "nsISupports.idl"
+
+[scriptable, uuid(6FC2117D-5EB4-441A-9C12-62A783BEBC0C)]
+interface nsPIDragServiceWindows : nsISupports
+{
+ void setIDataObject(in nsISupports aDataObj);
+
+ void setDroppedLocal();
+};
diff --git a/widget/xpwidgets/nsBaseDragService.cpp b/widget/xpwidgets/nsBaseDragService.cpp
index 342a036..87e28f7 100644
--- a/widget/xpwidgets/nsBaseDragService.cpp
+++ b/widget/xpwidgets/nsBaseDragService.cpp
@@ -88,7 +88,7 @@ nsBaseDragService::~nsBaseDragService()
{
}
-NS_IMPL_ISUPPORTS2(nsBaseDragService, nsIDragService, nsIDragSession)
+NS_IMPL_ISUPPORTS3(nsBaseDragService, nsIDragService, nsPIDragService, nsIDragSession)
//---------------------------------------------------------
NS_IMETHODIMP
@@ -436,6 +436,20 @@ nsBaseDragService::DragMoved(PRInt32 aX, PRInt32 aY)
return NS_OK;
}
+NS_IMETHODIMP
+nsBaseDragService::SetDragEndPoint(PRInt32 aX, PRInt32 aY)
+{
+ mEndDragPoint = nsIntPoint(aX, aY);
+ return NS_OK;
+}
+
+NS_IMETHODIMP
+nsBaseDragService::GetInputSource(PRUint16* aInputSource)
+{
+ *aInputSource = mInputSource;
+ return NS_OK;
+}
+
static nsIPresShell*
GetPresShellForContent(nsIDOMNode* aDOMNode)
{
diff --git a/widget/xpwidgets/nsBaseDragService.h b/widget/xpwidgets/nsBaseDragService.h
index 290c0cb..2ceac2b 100644
--- a/widget/xpwidgets/nsBaseDragService.h
+++ b/widget/xpwidgets/nsBaseDragService.h
@@ -39,6 +39,7 @@
#define nsBaseDragService_h__
#include "nsIDragService.h"
+#include "nsPIDragService.h"
#include "nsIDragSession.h"
#include "nsITransferable.h"
#include "nsISupportsArray.h"
@@ -64,6 +65,7 @@ class nsICanvasElementExternal;
*/
class nsBaseDragService : public nsIDragService,
+ public nsPIDragService,
public nsIDragSession
{
@@ -74,14 +76,11 @@ public:
//nsISupports
NS_DECL_ISUPPORTS
//nsIDragSession and nsIDragService
NS_DECL_NSIDRAGSERVICE
+ NS_DECL_NSPIDRAGSERVICE
NS_DECL_NSIDRAGSESSION
- void SetDragEndPoint(nsIntPoint aEndDragPoint) { mEndDragPoint = aEndDragPoint; }
-
- PRUint16 GetInputSource() { return mInputSource; }
-
protected:
/**
@@ -74,14 +76,11 @@ public:
//nsISupports
NS_DECL_ISUPPORTS
- //nsIDragSession and nsIDragService
+ //nsIDragSession, nsIDragService and nsPIDragService
NS_DECL_NSIDRAGSERVICE
--
1.7.5.4
|